#!/bin/sh

# All Rights Reserved * Licensed Materials - Property of IBM
# 5724-I63, 5724-H88, 5655-N01, 5733-W60 (C) COPYRIGHT International Business Machines Corp., 2010, 2011
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

# Utility to enable/disable VE

#
# TODO:
# (1) Remove any VE ifixes from all node-metadata.properties in the config repository, only on dmgr.
#

update_ve_registry_data ()  {

   REG_FILE=$1
   OPTION=$2
   HVE_USERNAME=$3
   TMPFILE="/opt/IBM/WebSphere/Profiles/properties/TMPFILE"
   echo "Profile registry file is $REG_FILE; the option is $OPTION"

   if [ -f ${REG_FILE} ]; then
      su $HVE_USERNAME -c "touch ${TMPFILE}"
      echo `ls -al ${TMPFILE}`
      if [ "$OPTION" = "enable" ] ; then
         echo "Enable VE.  Update the profile registry file."
         sed -e '/xd_augment/ s/<!--/</' -e '/xd_augment/ s/-->/>/'  ${REG_FILE} > ${TMPFILE}
         mv ${TMPFILE} ${REG_FILE}
      else
         echo "Disable VE.  Update the profile registry file."
         sed -e '/xd_augment/ s/<a/<!--a/' -e '/xd_augment/ s/\/>/\/-->/'  ${REG_FILE} > ${TMPFILE}
         mv ${TMPFILE} ${REG_FILE}
      fi
      echo `ls -al ${REG_FILE}`
   else
      echo "the profile registry file does not exist; exit the function"
   fi
}

if [ $# -lt 1 ]; then
  echo "Usage: ve.sh {enable|disable}"
  exit 1
fi
CMD=$1

OS=`uname -s`  
process=`uname -p`
#
# Initialize variables from /etc/virtualimage.properties file
#
WAS_INSTALL_ROOT="/opt/IBM/WebSphere/AppServer"
PROFILE_ROOT="/opt/IBM/WebSphere/Profiles"
XD_TEMPLATE_DIR=${WAS_INSTALL_ROOT}/profileTemplates/xd_augment
XD_TEMPLATE_HIDDEN_DIR=${WAS_INSTALL_ROOT}/profileTemplates/.xd_augment
ACTIONS_DIR="${XD_TEMPLATE_DIR}/actions"
PROFILE_NAMES="`$WAS_INSTALL_ROOT/bin/manageprofiles.sh -listProfiles`"
PROFILE_NAMES=`echo $PROFILE_NAMES | sed 's/\,//g'  | sed 's/\]//g' | sed 's/\[//g'`

if [ -f ${PROFILE_ROOT}/.ibm/username ]; then
   HVE_USERNAME=`cat ${PROFILE_ROOT}/.ibm/username`
else
   HVE_USERNAME="virtuser"
fi

echo "*** PROFILE_NAMES are ${PROFILE_NAMES}"
echo "*** User name is $HVE_USERNAME"

#
# Files to be renamed
#
PRODUCT="properties/version/WXDOP.product"
LICENSE="properties/version/WVE.license"
BASE="features/com.ibm.ws.xd.base_6.0.0.0/feature.xml"
ND="features/com.ibm.ws.xd.nd_6.0.0.0/feature.xml"
CIMGR="features/com.ibm.ws.xd.cimgr_6.1.0.0/feature.xml"
AUGMENT="properties/version/wxdop.augment"
ILMT="properties/version/WXDOP0700.sys2"
IMPILMT="virtual/TIVREADY/IMP0700.SYS2"
IMP="properties/version/IMP.product"
PMT="bin/ProfileManagement/plugins/com.ibm.ws.pmt.xd_7.0.0/plugin.xml"
PROFILE_REG_FILE="${PROFILE_ROOT}/properties/profileRegistry.xml"

INSTALL_FILES="${PRODUCT} ${LICENSE} ${BASE} ${ND} ${CIMGR} ${ILMT} ${IMPILMT} ${IMP} ${PMT}"
PROFILE_FILES="${AUGMENT}"

#
# Rename those files relative to the INSTALL directory which need
# to be renamed.
#
for rfile in $INSTALL_FILES
do
    file="${WAS_INSTALL_ROOT}/${rfile}"
    dfile="${file}."
    if [ "$CMD" = "enable" ]; then
       if [ -f $dfile ]; then
          mv $dfile $file
          echo "VE: Moved $dfile to $file"
       fi
    elif [ "$CMD" = "disable" ]; then
       if [ -f $file ]; then
          mv $file $dfile
          echo "VE: Moved $file to $dfile"
       fi
    else
       echo "Usage: ve.sh {enable|disable}"
       exit 1
    fi
done

if [ "$CMD" = "enable" ]; then
   if [ -d ${WAS_INSTALL_ROOT}/.license.ve ] ; then
      mv ${WAS_INSTALL_ROOT}/.license.ve ${WAS_INSTALL_ROOT}/license.ve
      echo "VE: Moved ${WAS_INSTALL_ROOT}/.license.ve to ${WAS_INSTALL_ROOT}/license.ve"
   fi
   if [ -d ${XD_TEMPLATE_HIDDEN_DIR} ] ; then
      mv ${XD_TEMPLATE_HIDDEN_DIR} ${XD_TEMPLATE_DIR}
      echo "VE: Moved ${XD_TEMPLATE_HIDDEN_DIR} to ${XD_TEMPLATE_DIR}"
   fi
fi
                                                                                                                                            
#
# Rename those files relative to the PROFILE directories which need
# to be renamed.
#
for PROFILE_NAME in $PROFILE_NAMES
do
   echo "*** PROFILE_NAME is ${PROFILE_NAME}"
   PROFILE_DIR="${PROFILE_ROOT}/${PROFILE_NAME}"
   if [ -f ${PROFILE_DIR}/${AUGMENT} ] || [ -f ${PROFILE_DIR}/${AUGMENT}. ]; then

      if [ "$PROFILE_NAME" = "DefaultDmgr01" ]; then
         PROCESS_TYPE="dmgr"
      elif [ "$PROFILE_NAME" = "DefaultCellDmgr01" ]; then
         PROCESS_TYPE="dmgr"
      fi

      for rfile in $PROFILE_FILES
      do
          file="${PROFILE_DIR}/${rfile}"
          dfile="${file}."
          if [ "$CMD" = "enable" ]; then
             if [ -f $dfile ]; then
                mv $dfile $file
                echo "VE: Moved $dfile to $file"
             fi
          else
             if [ -f $file ]; then
                mv $file $dfile
                echo "VE: Moved $file to $dfile"
             fi
          fi
      done

      if [ -f ${PROFILE_DIR}/bin/ws_ant.sh ]; then
         if [ "$CMD" = "enable" ] ; then
            echo "VE: Adding XD Features"
            su $HVE_USERNAME -c "${PROFILE_DIR}/bin/ws_ant.sh -file ${ACTIONS_DIR}/addXDHVFeature.ant -DWAS_HOME=${WAS_INSTALL_ROOT} -DprofilePath=${PROFILE_DIR} -DtemplatePath=${XD_TEMPLATE_DIR}"
         else
            echo "VE:Removing XD Features"
            su $HVE_USERNAME -c "${PROFILE_DIR}/bin/ws_ant.sh -file ${ACTIONS_DIR}/removeXDHVFeature.ant -DprofilePath=${PROFILE_DIR}"
         fi
      fi
      if [ "$PROCESS_TYPE" = "dmgr" ]; then
         if [ "$CMD" = "enable" ]; then
            echo "VE: Installing XD Portlet"
            su $HVE_USERNAME -c "${PROFILE_DIR}/bin/wsadmin.sh -conntype NONE -f ${ACTIONS_DIR}/installXDPortlet.py -lang jython -washome ${WAS_INSTALL_ROOT}"
            echo "VE: Disabling ARFM queueing"
            su $HVE_USERNAME -c "${PROFILE_DIR}/bin/wsadmin.sh -conntype NONE -f ${WAS_INSTALL_ROOT}/bin/disableARFM.py -lang jython -washome ${WAS_INSTALL_ROOT}"
         else
            echo "VE: Removing XD Portlet"
            su $HVE_USERNAME -c "${PROFILE_DIR}/bin/wsadmin.sh -conntype NONE -f ${ACTIONS_DIR}/removeXDPortlet.py -lang jython"
         fi
      fi
      update_ve_registry_data ${PROFILE_REG_FILE} ${CMD} ${HVE_USERNAME}      
   fi
done

if [ "$process" = "s390x" ]; then
   echo "VE: Running iscdeploy -restoreProfiles on zLinux"
   su $HVE_USERNAME -c "${WAS_INSTALL_ROOT}/bin/iscdeploy.sh -restoreProfiles"   
else
   echo "VE: Running iscdeploy -restore"   
   su $HVE_USERNAME -c "${WAS_INSTALL_ROOT}/bin/iscdeploy.sh -restore"
fi   

if [ "$CMD" = "disable" ]; then   
   if [ -d ${WAS_INSTALL_ROOT}/license.ve ] ; then
      mv ${WAS_INSTALL_ROOT}/license.ve ${WAS_INSTALL_ROOT}/.license.ve
      echo "VE: Moved ${WAS_INSTALL_ROOT}/license.ve to ${WAS_INSTALL_ROOT}/.license.ve"
   fi
fi

echo "VE: $CMD completed successfully"

exit 0
